Javascript · Twitter Bootstrap

# jQuery plugins A dozen Bootstrap plugins to get you started

### Modals

A streamlined, but flexible, take on the traditional javascript modal plugin with only the minimum required functionality and smart defaults.

### Dropdowns

Add dropdown menus to nearly anything in Bootstrap with this simple plugin. Bootstrap features full dropdown menu support on in the navbar, tabs, and pills.

### Scrollspy

Use scrollspy to automatically update the links in your navbar to show the current active link based on scroll position.

### Togglable tabs

Use this plugin to make tabs and pills more useful by allowing them to toggle through tabbable panes of local content.

### Tooltips

A new take on the jQuery Tipsy plugin, Tooltips don't rely on images—they use CSS3 for animations and data-attributes for local title storage.

### Popovers *

Add small overlays of content, like those on the iPad, to any element for housing secondary information.

* Requires Tooltips to be included

### Alert messages

The alert plugin is a tiny class for adding close functionality to alerts.

### Buttons

Do more with buttons. Control button states or create groups of buttons for more components like toolbars.

### Collapse

Get base styles and flexible support for collapsible components like accordions and navigation.

### Carousel

Create a merry-go-round of any content you wish to provide an interactive slideshow of content.

### Typeahead

A basic, easily extended plugin for quickly creating elegant typeaheads with any form text input.

### Transitions *

For simple transition effects, include bootstrap-transition.js once to slide in modals or fade out alerts.

* Required for animation in plugins

Heads up! All javascript plugins require the latest version of jQuery.

# Modals bootstrap-modal.js

### About modals

A streamlined, but flexible, take on the traditional javascript modal plugin with only the minimum required functionality and smart defaults.

Download file

## Static example

Below is a statically rendered modal.

### Modal header

One fine body…

## Live demo

Toggle a modal via javascript by clicking the button below. It will slide down and fade in from the top of the page.

### Modal Heading

#### Text in a modal

Duis mollis, est non commodo luctus, nisi erat porttitor ligula, eget lacinia odio sem.

#### Popover in a modal

This button should trigger a popover on hover.

#### Tooltips in a modal

This link and that link should have tooltips on hover.

#### Overflowing text to show optional scrollbar

We set a fixed `max-height` on the `.modal-body`. Watch it overflow with all this extra lorem ipsum text we've included.

Cras mattis consectetur purus sit amet fermentum. Cras justo odio, dapibus ac facilisis in, egestas eget quam. Morbi leo risus, porta ac consectetur ac, vestibulum at eros.

Praesent commodo cursus magna, vel scelerisque nisl consectetur et. Vivamus sagittis lacus vel augue laoreet rutrum faucibus dolor auctor.

Aenean lacinia bibendum nulla sed consectetur. Praesent commodo cursus magna, vel scelerisque nisl consectetur et. Donec sed odio dui. Donec ullamcorper nulla non metus auctor fringilla.

Cras mattis consectetur purus sit amet fermentum. Cras justo odio, dapibus ac facilisis in, egestas eget quam. Morbi leo risus, porta ac consectetur ac, vestibulum at eros.

Praesent commodo cursus magna, vel scelerisque nisl consectetur et. Vivamus sagittis lacus vel augue laoreet rutrum faucibus dolor auctor.

Aenean lacinia bibendum nulla sed consectetur. Praesent commodo cursus magna, vel scelerisque nisl consectetur et. Donec sed odio dui. Donec ullamcorper nulla non metus auctor fringilla.

Launch demo modal

## Using bootstrap-modal

Call the modal via javascript:

    $('#myModal').modal(options)

### Options

Name | type | default | description
--- | --- | --- | ---
backdrop | boolean | true | Includes a modal-backdrop element. Alternatively, specify `static` for a backdrop which doesn't close the modal on click.
keyboard | boolean | true | Closes the modal when escape key is pressed
show | boolean | true | Shows the modal when initialized.

### Markup

You can activate modals on your page easily without having to write a single line of javascript. Just set `data-toggle="modal"` on a controller element with a `data-target="#foo"` or `href="#foo"` which corresponds to a modal element id, and when clicked, it will launch your modal.

Also, to add options to your modal instance, just include them as additional data attributes on either the control element or the modal markup itself.

    <a class="btn" data-toggle="modal" href="#myModal" >Launch Modal</a>

    <div class="modal" id="myModal">
      <div class="modal-header">
        <button class="close" data-dismiss="modal">×</button>
        <h3>Modal header</h3>
      </div>
      <div class="modal-body">
        <p>One fine body…</p>
      </div>
      <div class="modal-footer">
        <a href="#" class="btn">Close</a>
        <a href="#" class="btn btn-primary">Save changes</a>
      </div>
    </div>

Heads up! If you want your modal to animate in and out, just add a `.fade` class to the `.modal` element (refer to the demo to see this in action) and include bootstrap-transition.js.

### Methods

#### .modal(options)

Activates your content as a modal. Accepts an optional options `object`.

    $('#myModal').modal({
      keyboard: false
    })

#### .modal('toggle')

Manually toggles a modal.

    $('#myModal').modal('toggle')

#### .modal('show')

Manually opens a modal.

    $('#myModal').modal('show')

#### .modal('hide')

Manually hides a modal.

    $('#myModal').modal('hide')

### Events

Bootstrap's modal class exposes a few events for hooking into modal functionality.

Event | Description
--- | ---
show | This event fires immediately when the `show` instance method is called.
shown | This event is fired when the modal has been made visible to the user (will wait for css transitions to complete).
hide | This event is fired immediately when the `hide` instance method has been called.
hidden | This event is fired when the modal has finished being hidden from the user (will wait for css transitions to complete).

    $('#myModal').on('hidden', function () {
      // do something…
    })

# Dropdowns bootstrap-dropdown.js

### About dropdowns

Add dropdown menus to nearly anything in Bootstrap with this simple plugin. Bootstrap features full dropdown menu support on in the navbar, tabs, and pills.

Download file

## Examples

Click on the dropdown nav links in the navbar and pills below to test dropdowns.

## Using bootstrap-dropdown.js

Call the dropdowns via javascript:

    $('.dropdown-toggle').dropdown()

### Markup

To quickly add dropdown functionality to any element just add `data-toggle="dropdown"` and any valid bootstrap dropdown will automatically be activated.

Heads up! You may optionally target a specific dropdown by using `data-target="#fat"` or `href="#fat"`.

    <ul class="nav nav-pills">
      <li class="active"><a href="#">Regular link</a></li>
      <li class="dropdown" id="menu1">
        <a class="dropdown-toggle" data-toggle="dropdown" href="#menu1">
          Dropdown
          <b class="caret"></b>
        </a>
        <ul class="dropdown-menu">
          <li><a href="#">Action</a></li>
          <li><a href="#">Another action</a></li>
          <li><a href="#">Something else here</a></li>
          <li class="divider"></li>
          <li><a href="#">Separated link</a></li>
        </ul>
      </li>
      ...
    </ul>

To keep URLs intact, use the `data-target` attribute instead of `href="#"`.

    <ul class="nav nav-pills">
      <li class="dropdown">
        <a class="dropdown-toggle" data-toggle="dropdown" data-target="#" href="path/to/page.html">
          Dropdown
          <b class="caret"></b>
        </a>
        <ul class="dropdown-menu">
          ...
        </ul>
      </li>
    </ul>

### Methods

#### $().dropdown()

A programatic api for activating menus for a given navbar or tabbed navigation.

# ScrollSpy bootstrap-scrollspy.js

The ScrollSpy plugin is for automatically updating nav targets based on scroll position.

Download file

## Example navbar with scrollspy

Scroll the area below and watch the navigation update. The dropdown sub items will be highlighted as well. Try it!

#### @fat

Ad leggings keytar, brunch id art party dolor labore. Pitchfork yr enim lo-fi before they sold out qui. Tumblr farm-to-table bicycle rights whatever. Anim keffiyeh carles cardigan. Velit seitan mcsweeney's photo booth 3 wolf moon irure. Cosby sweater lomo jean shorts, williamsburg hoodie minim qui you probably haven't heard of them et cardigan trust fund culpa biodiesel wes anderson aesthetic. Nihil tattooed accusamus, cred irony biodiesel keffiyeh artisan ullamco consequat.

#### @mdo

Veniam marfa mustache skateboard, adipisicing fugiat velit pitchfork beard. Freegan beard aliqua cupidatat mcsweeney's vero. Cupidatat four loko nisi, ea helvetica nulla carles. Tattooed cosby sweater food truck, mcsweeney's quis non freegan vinyl. Lo-fi wes anderson +1 sartorial. Carles non aesthetic exercitation quis gentrify. Brooklyn adipisicing craft beer vice keytar deserunt.

#### one

Occaecat commodo aliqua delectus. Fap craft beer deserunt skateboard ea. Lomo bicycle rights adipisicing banh mi, velit ea sunt next level locavore single-origin coffee in magna veniam. High life id vinyl, echo park consequat quis aliquip banh mi pitchfork. Vero VHS est adipisicing. Consectetur nisi DIY minim messenger bag. Cred ex in, sustainable delectus consectetur fanny pack iphone.

#### two

In incididunt echo park, officia deserunt mcsweeney's proident master cleanse thundercats sapiente veniam. Excepteur VHS elit, proident shoreditch +1 biodiesel laborum craft beer. Single-origin coffee wayfarers irure four loko, cupidatat terry richardson master cleanse. Assumenda you probably haven't heard of them art party fanny pack, tattooed nulla cardigan tempor ad. Proident wolf nesciunt sartorial keffiyeh eu banh mi sustainable. Elit wolf voluptate, lo-fi ea portland before they sold out four loko. Locavore enim nostrud mlkshk brooklyn nesciunt.

#### three

Ad leggings keytar, brunch id art party dolor labore. Pitchfork yr enim lo-fi before they sold out qui. Tumblr farm-to-table bicycle rights whatever. Anim keffiyeh carles cardigan. Velit seitan mcsweeney's photo booth 3 wolf moon irure. Cosby sweater lomo jean shorts, williamsburg hoodie minim qui you probably haven't heard of them et cardigan trust fund culpa biodiesel wes anderson aesthetic. Nihil tattooed accusamus, cred irony biodiesel keffiyeh artisan ullamco consequat.

Keytar twee blog, culpa messenger bag marfa whatever delectus food truck. Sapiente synth id assumenda. Locavore sed helvetica cliche irony, thundercats you probably haven't heard of them consequat hoodie gluten-free lo-fi fap aliquip. Labore elit placeat before they sold out, terry richardson proident brunch nesciunt quis cosby sweater pariatur keffiyeh ut helvetica artisan. Cardigan craft beer seitan readymade velit. VHS chambray laboris tempor veniam. Anim mollit minim commodo ullamco thundercats.

## Using bootstrap-scrollspy.js

Call the scrollspy via javascript:

    $('#navbar').scrollspy()

### Markup

To easily add scrollspy behavior to your topbar navigation, just add `data-spy="scroll"` to the element you want to spy on (most typically this would be the body).

    <body data-spy="scroll" >...</body>

Heads up! Navbar links must have resolvable id targets. For example, a `<a href="#home">home</a>` must correspond to something in the dom like `<div id="home"></div>`.

### Methods

#### .scrollspy('refresh')

When using scrollspy in conjunction with adding or removing of elements from the DOM, you'll need to call the refresh method like so:

    $('[data-spy="scroll"]').each(function () {
      var $spy = $(this).scrollspy('refresh')
    });

### Options

Name | type | default | description
--- | --- | --- | ---
offset | number | 10 | Pixels to offset from top when calculating position of scroll.

### Events

Event | Description
--- | ---
activate | This event fires whenever a new item becomes activated by the scrollspy.

# Togglable tabs bootstrap-tab.js

This plugin adds quick, dynamic tab and pill functionality for transitioning through local content.

Download file

## Example tabs

Click the tabs below to toggle between hidden panes, even via dropdown menus.

Raw denim you probably haven't heard of them jean shorts Austin. Nesciunt tofu stumptown aliqua, retro synth master cleanse. Mustache cliche tempor, williamsburg carles vegan helvetica. Reprehenderit butcher retro keffiyeh dreamcatcher synth. Cosby sweater eu banh mi, qui irure terry richardson ex squid. Aliquip placeat salvia cillum iphone. Seitan aliquip quis cardigan american apparel, butcher voluptate nisi qui.

Food truck fixie locavore, accusamus mcsweeney's marfa nulla single-origin coffee squid. Exercitation +1 labore velit, blog sartorial PBR leggings next level wes anderson artisan four loko farm-to-table craft beer twee. Qui photo booth letterpress, commodo enim craft beer mlkshk aliquip jean shorts ullamco ad vinyl cillum PBR. Homo nostrud organic, assumenda labore aesthetic magna delectus mollit. Keytar helvetica VHS salvia yr, vero magna velit sapiente labore stumptown. Vegan fanny pack odio cillum wes anderson 8-bit, sustainable jean shorts beard ut DIY ethical culpa terry richardson biodiesel. Art party scenester stumptown, tumblr butcher vero sint qui sapiente accusamus tattooed echo park.

Etsy mixtape wayfarers, ethical wes anderson tofu before they sold out mcsweeney's organic lomo retro fanny pack lo-fi farm-to-table readymade. Messenger bag gentrify pitchfork tattooed craft beer, iphone skateboard locavore carles etsy salvia banksy hoodie helvetica. DIY synth PBR banksy irony. Leggings gentrify squid 8-bit cred pitchfork. Williamsburg banh mi whatever gluten-free, carles pitchfork biodiesel fixie etsy retro mlkshk vice blog. Scenester cred you probably haven't heard of them, vinyl craft beer blog stumptown. Pitchfork sustainable tofu synth chambray yr.

Trust fund seitan letterpress, keytar raw denim keffiyeh etsy art party before they sold out master cleanse gluten-free squid scenester freegan cosby sweater. Fanny pack portland seitan DIY, art party locavore wolf cliche high life echo park Austin. Cred vinyl keffiyeh DIY salvia PBR, banh mi before they sold out farm-to-table VHS viral locavore cosby sweater. Lomo wolf viral, mustache readymade thundercats keffiyeh craft beer marfa ethical. Wolf salvia freegan, sartorial keffiyeh echo park vegan.

## Using bootstrap-tab.js

Enable tabbable tabs via javascript (each tab needs to be activated individually):

    $('#myTab a').click(function (e) {
      e.preventDefault();
      $(this).tab('show');
    })

You can activate individual tabs in several ways:

    $('#myTab a[href="#profile"]').tab('show'); // Select tab by name
    $('#myTab a:first').tab('show'); // Select first tab
    $('#myTab a:last').tab('show'); // Select last tab
    $('#myTab li:eq(2) a').tab('show'); // Select third tab (0-indexed)

### Markup

You can activate a tab or pill navigation without writing any javascript by simply specifying `data-toggle="tab"` or `data-toggle="pill"` on an element. Adding the `nav` and `nav-tabs` classes to the tab `ul` will apply the bootstrap tab styling.

    <ul class="nav nav-tabs">
      <li><a href="#home" data-toggle="tab">Home</a></li>
      <li><a href="#profile" data-toggle="tab">Profile</a></li>
      <li><a href="#messages" data-toggle="tab">Messages</a></li>
      <li><a href="#settings" data-toggle="tab">Settings</a></li>
    </ul>

### Methods

#### $().tab

Activates a tab element and content container. Tab should have either a `data-target` or an `href` targeting a container node in the DOM.

    <ul class="nav nav-tabs" id="myTab">
      <li class="active"><a href="#home">Home</a></li>
      <li><a href="#profile">Profile</a></li>
      <li><a href="#messages">Messages</a></li>
      <li><a href="#settings">Settings</a></li>
    </ul>

    <div class="tab-content">
      <div class="tab-pane active" id="home">...</div>
      <div class="tab-pane" id="profile">...</div>
      <div class="tab-pane" id="messages">...</div>
      <div class="tab-pane" id="settings">...</div>
    </div>

    <script>
      $(function () {
        $('#myTab a:last').tab('show');
      })
    </script>

### Events

Event | Description
--- | ---
show | This event fires on tab show, but before the new tab has been shown. Use `event.target` and `event.relatedTarget` to target the active tab and the previous active tab (if available) respectively.
shown | This event fires on tab show after a tab has been shown. Use `event.target` and `event.relatedTarget` to target the active tab and the previous active tab (if available) respectively.

    $('a[data-toggle="tab"]').on('shown', function (e) {
      e.target // activated tab
      e.relatedTarget // previous tab
    })

# Tooltips bootstrap-tooltip.js

### About Tooltips

Inspired by the excellent jQuery.tipsy plugin written by Jason Frame; Tooltips are an updated version, which don't rely on images, use css3 for animations, and data-attributes for local title storage.

Download file

## Example use of Tooltips

Hover over the links below to see tooltips:

Tight pants next level keffiyeh you probably haven't heard of them. Photo booth beard raw denim letterpress vegan messenger bag stumptown. Farm-to-table seitan, mcsweeney's fixie sustainable quinoa 8-bit american apparel have a terry richardson vinyl chambray. Beard stumptown, cardigans banh mi lomo thundercats. Tofu biodiesel williamsburg marfa, four loko mcsweeney's cleanse vegan chambray. A really ironic artisan whatever keytar, scenester farm-to-table banksy Austin twitter handle freegan cred raw denim single-origin coffee viral.

## Using bootstrap-tooltip.js

Trigger the tooltip via javascript:

    $('#example').tooltip(options)

### Options

Name | type | default | description
--- | --- | --- | ---
animation | boolean | true | apply a css fade transition to the tooltip
placement | string|function | 'top' | how to position the tooltip - top | bottom | left | right
selector | string | false | If a selector is provided, tooltip objects will be delegated to the specified targets.
title | string | function | '' | default title value if `title` tag isn't present
trigger | string | 'hover' | how tooltip is triggered - hover | focus | manual
delay | number | object | 0 | delay showing and hiding the tooltip (ms) - does not apply to manual trigger type If a number is supplied, delay is applied to both hide/show Object structure is: `delay: { show: 500, hide: 100 }`

Heads up! Options for individual tooltips can alternatively be specified through the use of data attributes.

### Markup

For performance reasons, the Tooltip and Popover data-apis are opt in. If you would like to use them just specify a selector option.

    <a href="#" rel="tooltip" title="first tooltip">hover over me</a>

### Methods

#### $().tooltip(options)

Attaches a tooltip handler to an element collection.

#### .tooltip('show')

Reveals an element's tooltip.

    $('#element').tooltip('show')

#### .tooltip('hide')

Hides an element's tooltip.

    $('#element').tooltip('hide')

#### .tooltip('toggle')

Toggles an element's tooltip.

    $('#element').tooltip('toggle')

# Popovers bootstrap-popover.js

### About popovers

Add small overlays of content, like those on the iPad, to any element for housing secondary information.

* Requires Tooltip to be included

Download file

## Example hover popover

Hover over the button to trigger the popover.

hover for popover

## Using bootstrap-popover.js

Enable popovers via javascript:

    $('#example').popover(options)

### Options

Name | type | default | description
--- | --- | --- | ---
animation | boolean | true | apply a css fade transition to the tooltip
placement | string|function | 'right' | how to position the popover - top | bottom | left | right
selector | string | false | if a selector is provided, tooltip objects will be delegated to the specified targets
trigger | string | 'hover' | how tooltip is triggered - hover | focus | manual
title | string | function | '' | default title value if `title` attribute isn't present
content | string | function | '' | default content value if `data-content` attribute isn't present
delay | number | object | 0 | delay showing and hiding the popover (ms) - does not apply to manual trigger type If a number is supplied, delay is applied to both hide/show Object structure is: `delay: { show: 500, hide: 100 }`

Heads up! Options for individual popovers can alternatively be specified through the use of data attributes.

### Markup

For performance reasons, the Tooltip and Popover data-apis are opt in. If you would like to use them just specify a selector option.

### Methods

#### $().popover(options)

Initializes popovers for an element collection.

#### .popover('show')

Reveals an elements popover.

    $('#element').popover('show')

#### .popover('hide')

Hides an elements popover.

    $('#element').popover('hide')

#### .popover('toggle')

Toggles an elements popover.

    $('#element').popover('toggle')

# Alert messages bootstrap-alert.js

### About alerts

The alert plugin is a tiny class for adding close functionality to alerts.

Download

## Example alerts

The alerts plugin works on regular alert messages, and block messages.

Holy guacamole! Best check yo self, you're not looking too good.

#### Oh snap! You got an error!

Change this and that and try again. Duis mollis, est non commodo luctus, nisi erat porttitor ligula, eget lacinia odio sem nec elit. Cras mattis consectetur purus sit amet fermentum.

Take this action Or do this

## Using bootstrap-alert.js

Enable dismissal of an alert via javascript:

    $(".alert").alert()

### Markup

Just add `data-dismiss="alert"` to your close button to automatically give an alert close functionality.

    <a class="close" data-dismiss="alert" href="#">&times;</a>

### Methods

#### $().alert()

Wraps all alerts with close functionality. To have your alerts animate out when closed, make sure they have the `.fade` and `.in` class already applied to them.

#### .alert('close')

Closes an alert.

    $(".alert").alert('close')

### Events

Bootstrap's alert class exposes a few events for hooking into alert functionality.

Event | Description
--- | ---
close | This event fires immediately when the `close` instance method is called.
closed | This event is fired when the alert has been closed (will wait for css transitions to complete).

    $('#my-alert').bind('closed', function () {
      // do something…
    })

# Buttons bootstrap-button.js

### About

Do more with buttons. Control button states or create groups of buttons for more components like toolbars.

Download file

## Example uses

Use the buttons plugin for states and toggles.

Stateful |
Single toggle |
Checkbox |
Radio |

## Using bootstrap-button.js

Enable buttons via javascript:

    $('.nav-tabs').button()

### Markup

Data attributes are integral to the button plugin. Check out the example code below for the various markup types.

    <!-- Add data-toggle="button" to activate toggling on a single button -->
    <button class="btn" data-toggle="button">Single Toggle</button>

    <!-- Add data-toggle="buttons-checkbox" for checkbox style toggling on btn-group -->
    <div class="btn-group" data-toggle="buttons-checkbox">
      <button class="btn">Left</button>
      <button class="btn">Middle</button>
      <button class="btn">Right</button>
    </div>

    <!-- Add data-toggle="buttons-radio" for radio style toggling on btn-group -->
    <div class="btn-group" data-toggle="buttons-radio">
      <button class="btn">Left</button>
      <button class="btn">Middle</button>
      <button class="btn">Right</button>
    </div>

### Methods

#### $().button('toggle')

Toggles push state. Gives the button the appearance that it has been activated.

Heads up! You can enable auto toggling of a button by using the `data-toggle` attribute.

    <button class="btn" data-toggle="button" >…</button>

#### $().button('loading')

Sets button state to loading - disables button and swaps text to loading text. Loading text should be defined on the button element using the data attribute `data-loading-text`.

    <button class="btn" data-loading-text="loading stuff..." >...</button>

Heads up! Firefox persists the disabled state across page loads. A workaround for this is to use `autocomplete="off"`.

#### $().button('reset')

Resets button state - swaps text to original text.

#### $().button(string)

Resets button state - swaps text to any data defined text state.

    <button class="btn" data-complete-text="finished!" >...</button>
    <script>
      $('.btn').button('complete')
    </script>

# Collapse bootstrap-collapse.js

### About

Get base styles and flexible support for collapsible components like accordions and navigation.

Download file

* Requires the Transitions plugin to be included.

## Example accordion

Using the collapse plugin, we built a simple accordion style widget:

Collapsible Group Item #1
Anim pariatur cliche reprehenderit, enim eiusmod high life accusamus terry richardson ad squid. 3 wolf moon officia aute, non cupidatat skateboard dolor brunch. Food truck quinoa nesciunt laborum eiusmod. Brunch 3 wolf moon tempor, sunt aliqua put a bird on it squid single-origin coffee nulla assumenda shoreditch et. Nihil anim keffiyeh helvetica, craft beer labore wes anderson cred nesciunt sapiente ea proident. Ad vegan excepteur butcher vice lomo. Leggings occaecat craft beer farm-to-table, raw denim aesthetic synth nesciunt you probably haven't heard of them accusamus labore sustainable VHS.
Collapsible Group Item #2
Anim pariatur cliche reprehenderit, enim eiusmod high life accusamus terry richardson ad squid. 3 wolf moon officia aute, non cupidatat skateboard dolor brunch. Food truck quinoa nesciunt laborum eiusmod. Brunch 3 wolf moon tempor, sunt aliqua put a bird on it squid single-origin coffee nulla assumenda shoreditch et. Nihil anim keffiyeh helvetica, craft beer labore wes anderson cred nesciunt sapiente ea proident. Ad vegan excepteur butcher vice lomo. Leggings occaecat craft beer farm-to-table, raw denim aesthetic synth nesciunt you probably haven't heard of them accusamus labore sustainable VHS.
Collapsible Group Item #3
Anim pariatur cliche reprehenderit, enim eiusmod high life accusamus terry richardson ad squid. 3 wolf moon officia aute, non cupidatat skateboard dolor brunch. Food truck quinoa nesciunt laborum eiusmod. Brunch 3 wolf moon tempor, sunt aliqua put a bird on it squid single-origin coffee nulla assumenda shoreditch et. Nihil anim keffiyeh helvetica, craft beer labore wes anderson cred nesciunt sapiente ea proident. Ad vegan excepteur butcher vice lomo. Leggings occaecat craft beer farm-to-table, raw denim aesthetic synth nesciunt you probably haven't heard of them accusamus labore sustainable VHS.

## Using bootstrap-collapse.js

Enable via javascript:

    $(".collapse").collapse()

### Options

Name | type | default | description
--- | --- | --- | ---
parent | selector | false | If selector then all collapsible elements under the specified parent will be closed when this collapsible item is shown. (similar to traditional accordion behavior)
toggle | boolean | true | Toggles the collapsible element on invocation

### Markup

Just add `data-toggle="collapse"` and a `data-target` to element to automatically assign control of a collapsible element. The `data-target` attribute accepts a css selector to apply the collapse to. Be sure to add the class `collapse` to the collapsible element. If you'd like it to default open, add the additional class `in`.

    <button class="btn btn-danger" data-toggle="collapse" data-target="#demo">
      simple collapsible
    </button>

    <div id="demo" class="collapse in"> … </div>

Heads up! To add accordion-like group management to a collapsible control, add the data attribute `data-parent="#selector"`. Refer to the demo to see this in action.

### Methods

#### .collapse(options)

Activates your content as a collapsible element. Accepts an optional options `object`.

    $('#myCollapsible').collapse({
      toggle: false
    })

#### .collapse('toggle')

Toggles a collapsible element to shown or hidden.

#### .collapse('show')

Shows a collapsible element.

#### .collapse('hide')

Hides a collapsible element.

### Events

Bootstrap's collapse class exposes a few events for hooking into collapse functionality.

Event | Description
--- | ---
show | This event fires immediately when the `show` instance method is called.
shown | This event is fired when a collapse element has been made visible to the user (will wait for css transitions to complete).
hide | This event is fired immediately when the `hide` method has been called.
hidden | This event is fired when a collapse element has been hidden from the user (will wait for css transitions to complete).

    $('#myCollapsible').on('hidden', function () {
      // do something…
    })

# Carousel bootstrap-carousel.js

### About

A generic plugin for cycling through elements. A merry-go-round.

Download file

## Example carousel

Watch the slideshow below.

#### First Thumbnail label

Cras justo odio, dapibus ac facilisis in, egestas eget quam. Donec id elit non mi porta gravida at eget metus. Nullam id dolor id nibh ultricies vehicula ut id elit.

#### Second Thumbnail label

Cras justo odio, dapibus ac facilisis in, egestas eget quam. Donec id elit non mi porta gravida at eget metus. Nullam id dolor id nibh ultricies vehicula ut id elit.

#### Third Thumbnail label

Cras justo odio, dapibus ac facilisis in, egestas eget quam. Donec id elit non mi porta gravida at eget metus. Nullam id dolor id nibh ultricies vehicula ut id elit.

‹ ›
Heads up! When implementing this carousel, remove the images we have provided and replace them with your own.

## Using bootstrap-carousel.js

Call via javascript:

    $('.carousel').carousel()

### Options

Name | type | default | description
--- | --- | --- | ---
interval | number | 5000 | The amount of time to delay between automatically cycling an item. If false, carousel will not automatically cycle.
pause | string | "hover" | Pauses the cycling of the carousel on mouseenter and resumes the cycling of the carousel on mouseleave.

### Markup

Data attributes are used for the previous and next conrols. Check out the example markup below.

    <div id="myCarousel" class="carousel">
      <!-- Carousel items -->
      <div class="carousel-inner">
        <div class="active item">…</div>
        <div class="item">…</div>
        <div class="item">…</div>
      </div>
      <!-- Carousel nav -->
      <a class="carousel-control left" href="#myCarousel" data-slide="prev">&lsaquo;</a>
      <a class="carousel-control right" href="#myCarousel" data-slide="next">&rsaquo;</a>
    </div>

### Methods

#### .carousel(options)

Initializes the carousel with an optional options `object` and starts cycling through items.

    $('.carousel').carousel({
      interval: 2000
    })

#### .carousel('cycle')

Cycles through the carousel items from left to right.

#### .carousel('pause')

Stops the carousel from cycling through items.

#### .carousel(number)

Cycles the carousel to a particular frame (0 based, similar to an array).

#### .carousel('prev')

Cycles to the previous item.

#### .carousel('next')

Cycles to the next item.

### Events

Bootstrap's carousel class exposes two events for hooking into carousel functionality.

Event | Description
--- | ---
slide | This event fires immediately when the `slide` instance method is invoked.
slid | This event is fired when the carousel has completed its slide transition.

# Typeahead bootstrap-typeahead.js

### About

A basic, easily extended plugin for quickly creating elegant typeaheads with any form text input.

Download file

## Example

Start typing in the field below to show the typeahead results.

## Using bootstrap-typeahead.js

Call the typeahead via javascript:

    $('.typeahead').typeahead()

### Options

Name | type | default | description
--- | --- | --- | ---
source | array | [ ] | The data source to query against.
items | number | 8 | The max number of items to display in the dropdown.
matcher | function | case insensitive | The method used to determine if a query matches an item. Accepts a single argument, the `item` against which to test the query. Access the current query with `this.query`. Return a boolean `true` if query is a match.
sorter | function | exact match, case sensitive, case insensitive | Method used to sort autocomplete results. Accepts a single argument `items` and has the scope of the typeahead instance. Reference the current query with `this.query`.
highlighter | function | highlights all default matches | Method used to highlight autocomplete results. Accepts a single argument `item` and has the scope of the typeahead instance. Should return html.

### Markup

Add data attributes to register an element with typeahead functionality.

    <input type="text" data-provide="typeahead">

### Methods

#### .typeahead(options)

Initializes an input with a typeahead.